@@ -1,5 +1,5 @@
 __author__ = "Henry Rosales-Méndez"
-__version__ = "0.0.2"
+__version__ = "0.0.3"
 __maintainer__ = "Henry Rosales-Méndez"
 __email__ = "hrosmendez@gmail.com"
 __status__ = "beta"
@@ -102,7 +102,10 @@ class DDL_Handler:
                     continue
             
             elif state == 102:
-                if ch in [' ','\t','\n']:
+                if ch == ')':
+                    state = 103
+                    i = i-1
+                elif ch in [' ','\t','\n',',']:
                     state = 103
                     comment = ''
                 else:
